#ifndef NT2_INCLUDE_FUNCTIONS_REALSQRT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REALSQRT_HPP_INCLUDED

#include <nt2/exponential/include/functions/realsqrt.hpp>

#endif
